'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var GetClassName = function (classNameBase, additionalClassList) {
    return (additionalClassList === undefined || additionalClassList.length == 0)
        ? classNameBase
        : classNameBase + " " + additionalClassList.join(" ");
};

var GETRequest = function (url) {
    var options = {
        method: 'GET',
        mode: 'cors',
        cache: 'no-cache',
        credentials: 'same-origin',
        headers: { 'Content-Type': 'application/json' },
        redirect: 'follow',
        referrerPolicy: 'no-referrer'
    };
    var res = null;
    fetch(url, options)
        .then(function (response) { return response.json(); })
        .then(function (data) { return res = data; });
    return res;
};

var POSTRequest = function (url, body) {
    var options = {
        method: 'POST',
        mode: 'cors',
        cache: 'no-cache',
        credentials: 'same-origin',
        headers: { 'Content-Type': 'application/json' },
        redirect: 'follow',
        referrerPolicy: 'no-referrer',
        body: JSON.stringify({ data: body })
    };
    var res = null;
    fetch(url, options)
        .then(function (response) { return response.json(); })
        .then(function (data) { return res = data; });
    return res;
};

var GetCookie = function (cname) {
    var name = cname + "=";
    var decodedCookie = decodeURIComponent(document.cookie);
    var ca = decodedCookie.split(';');
    for (var i = 0; i < ca.length; i++) {
        var c = ca[i];
        while (c.charAt(0) == ' ') {
            c = c.substring(1);
        }
        if (c.indexOf(name) == 0) {
            return c.substring(name.length, c.length);
        }
    }
    return "";
};

var GetExpireDate = function () {
    var now = new Date();
    var time = now.getTime();
    var expireTime = time + 3600 * 1000 * 24 * 366 * 10;
    now.setTime(expireTime);
    return now;
};

var ScrollSmoothly = function () {
    window.scrollTo({
        top: 0,
        left: 0,
        behavior: 'smooth'
    });
};

exports.GETRequest = GETRequest;
exports.GetClassName = GetClassName;
exports.GetCookie = GetCookie;
exports.GetExpireDate = GetExpireDate;
exports.POSTRequest = POSTRequest;
exports.ScrollSmoothly = ScrollSmoothly;
//# sourceMappingURL=index.js.map
